@@ -69,6 +69,7 @@ Account::Account()
    showEmail_(true),
    showMessageTime_(true),
    showNowListening_(false),
+   showListPictures_(false),
    showOfflineContacts_(true),
    showOtherFolders_(true),
    showRemovedContacts_(false),
@@ -131,6 +132,7 @@ void Account::copyAccount( const Account *account )
   setShowContactsByGroup     ( account->getShowContactsByGroup() );
   setShowOfflineContacts     ( account->getShowOfflineContacts() );
   setShowRemovedContacts     ( account->getShowRemovedContacts() );
+  setShowListPictures        ( account->getShowListPictures()    );
   setEmoticonStyle           ( account->getEmoticonStyle()       );
 
   setAlertsInformation       ( account->getUseIdleTimer(),
@@ -190,6 +192,7 @@ void Account::copyAccountUISettings( const Account *account )
   setShowOfflineContacts( account->getShowOfflineContacts() );
   setShowRemovedContacts( account->getShowRemovedContacts() );
   setShowContactsByGroup( account->getShowContactsByGroup() );
+  setShowListPictures   ( account->getShowListPictures()    );
   setAutoreplyMessage   ( account->getAutoreplyMessage()    );
   setEmailSupported     ( account->getEmailSupported()      );
   setGuestAccount       ( account->isGuestAccount()         );
@@ -607,6 +610,13 @@ bool Account::getShowImage() const
 }
 
 
+// Returns whether display pictures should be shown in contact list
+bool Account::getShowListPictures() const
+{
+  return showListPictures_;
+}
+
+
 
 // Return the path of the custom display image.
 const QString Account::getCustomImagePath() const
@@ -741,6 +751,7 @@ void Account::readProperties(KConfig *config, QString handle)
   showContactsByGroup_           = config->readBoolEntry( "showByGroup",                  true                              );
   showEmail_                     = config->readBoolEntry( "showEmail",                    true                              );
   showImage_                     = config->readBoolEntry( "showImage",                    true                              );
+  showListPictures_              = config->readBoolEntry( "showListPictures",             false                             );
   showMessageTime_               = config->readBoolEntry( "showMessageTime",              true                              );
   showNowListening_              = config->readBoolEntry( "showNowListening",             false                             );
   showOfflineContacts_           = config->readBoolEntry( "showOfflineContacts",          true                              );
@@ -860,6 +871,7 @@ void Account::saveProperties(KConfig *config)
     config->writeEntry( "showAllowed",                  showAllowedContacts_          );
     config->writeEntry( "showByGroup",                  showContactsByGroup_          );
     config->writeEntry( "showEmail",                    showEmail_                    );
+    config->writeEntry( "showListPictures",             showListPictures_             );
     config->writeEntry( "showMessageTime",              showMessageTime_              );
     config->writeEntry( "showNowListening",             showNowListening_             );
     config->writeEntry( "showOfflineContacts",          showOfflineContacts_          );
@@ -1192,8 +1204,13 @@ void Account::setLoginInformation( QString handle, QString friendlyName, QString
   ||  ( ! password.isEmpty() && password != password_ ) )
   {
     handle_       = handle.lower();
-    friendlyName_ = friendlyName;
-    emit changedFriendlyName();
+
+    // Never change the nickname if the account is not verified. We would receive a server error
+    if( verified_ )
+    {
+      friendlyName_ = friendlyName;
+      emit changedFriendlyName();
+    }
 
     if( ! password.isEmpty() )
     {
@@ -1411,6 +1428,26 @@ void Account::setShowImage( bool showImage )
 
 
 
+// Set whether the display pictures of the contacts should be shown in list
+void Account::setShowListPictures( bool showPictures)
+{
+  // No need to update
+  if( showPictures == showListPictures_ )
+  {
+    return;
+  }
+
+  showListPictures_ = showPictures;
+  emit changedDisplaySettings();
+  dirty_ = true;
+
+#ifdef KMESSDEBUG_ACCOUNT_DIRTY
+  kdDebug() << "Account::setShowListPictures(): Setting 'dirty' to true." << endl;
+#endif
+}
+
+
+
 // Creates the MsnObject only if the user wants to show a display picture
 void Account::updateMsnObject()
 {
