@@ -118,6 +118,8 @@ class Account : public QObject
     bool                         getShowContactsByGroup() const;
     // Read whether the email information should be shown in the main view.
     bool                         getShowEmail() const;
+    // Returns whether display pictures should be shown in contact list.
+    bool                         getShowListPictures() const;
     // Read the selected emoticon's list number
     const QString&               getEmoticonStyle() const;
     // Read whether the chat window should shake when a nudge is received or sent.
@@ -220,6 +222,8 @@ class Account : public QObject
     void                         setShowAllowedContacts( bool showAllowedContacts );
     // Set whether contacts are shown by group or by online/offline.
     void                         setShowContactsByGroup( bool showContactsByGroup );
+    // Set whether the display pictures of the contacts should be shown in list
+    void                         setShowListPictures( bool showPictures);
     // Set whether offline contacts should be shown.
     void                         setShowOfflineContacts( bool showOfflineContacts );
     // Set whether or not removed (reverse) contacts are shown.
@@ -316,6 +320,8 @@ class Account : public QObject
     bool                         showMessageTime_;
     // Whether now listening information should be shown or not.
     bool                         showNowListening_;
+    // Whether or not display pictures are shown.
+    bool                         showListPictures_;
     // Whether or not offline contacts are shown.
     bool                         showOfflineContacts_;
     // Whether or not notifications should be shown for "other folder" email.
