@@ -27,7 +27,6 @@
 #include <qstringlist.h>
 #include <qtextbrowser.h>
 #include <qtextcodec.h>
-#include <qtextedit.h>
 #include <qtoolbox.h>
 
 #include <kaction.h>
@@ -42,6 +41,7 @@
 #include <krun.h>
 #include <kstddirs.h>
 #include <ktextbrowser.h>
+#include <ktextedit.h>
 #include <kurl.h>
 
 #include "chatmessage.h"
@@ -155,6 +155,10 @@ bool ChatView::eventFilter( QObject */*obj*/, QEvent *event )
 
   switch( event->type() )
   {
+    case QEvent::WindowActivate:
+      messageEdit_->setFocus();
+      break;
+
     case QEvent::DragEnter:
       dropEvent->accept( QUriDrag::decodeLocalFiles( dropEvent, fileList ) );
       break;
