@@ -26,7 +26,6 @@
 #include <qregexp.h>
 #include <qstylesheet.h>
 #include <qtextcodec.h>
-#include <qtextedit.h>
 #include <qtoolbox.h>
 
 #include <kaction.h>
@@ -42,7 +41,9 @@
 #include <kprocess.h>
 #include <kstatusbar.h>
 #include <ksqueezedtextlabel.h>
+#include <ksyntaxhighlighter.h>
 #include <ktextbrowser.h>
+#include <ktextedit.h>
 #include <ktoolbarbutton.h>
 
 #include "../actions/accountaction.h"
@@ -97,6 +98,9 @@ ChatWindow::ChatWindow(QWidget *parent, const char *name )
   caption_ = i18n("Chat");
   setCaption( caption_ );
 
+  // Install a filter to catch window activation events, to stop title blinking
+  installEventFilter( this );
+
   // Connect the blink timer
   connect( &blinkTimer_, SIGNAL(      timeout() ),
            this,         SLOT  ( blinkCaption() ) );
@@ -141,30 +145,46 @@ ChatWindow::~ChatWindow()
 
 
 
+// Filter to catch window activation events
+bool ChatWindow::eventFilter( QObject */*obj*/, QEvent *event )
+{
+  // Stop blinking if the window is active
+  if( blinkTimer_.isActive() && event->type() == QEvent::WindowActivate )
+  {
+    blinkTimer_.stop();
+    setCaption( caption_ );
+  }
+
+  return false;
+}
+
+
+
 // Make the caption blink if the window still doesn't have focus
 void ChatWindow::blinkCaption()
 {
-  // If the window now has focus...
-  if ( isActiveWindow() /*hasMouse()*/ )
+  // If the window now has focus, stop blinking
+  if( isActiveWindow() )
   {
     // Stop the timer
     blinkTimer_.stop();
-    // Reset the caption
+
+    // Reset the caption to normal
     setCaption( caption_ );
+    return;
+  }
+
+  // Make the caption alternate case
+  if ( blinkToUpper_ )
+  {
+    setCaption( QString( "* " + caption_.upper() ) );
   }
   else
   {
-    // Make the caption alternate case
-    if ( blinkToUpper_ )
-    {
-      setCaption( QString( "* " + caption_.upper() ) );
-    }
-    else
-    {
-      setCaption( QString( "* " + caption_.lower() ) );
-    }
-    blinkToUpper_ = !blinkToUpper_;
+    setCaption( QString( "* " + caption_.lower() ) );
   }
+
+  blinkToUpper_ = ! blinkToUpper_;
 }
 
 
@@ -1100,10 +1120,15 @@ void ChatWindow::readProperties( KConfig *config )
   kdDebug() << "ChatWindow::readProperties() - Reading saved properties." << endl;
 #endif
 
+  // First save the general interface settings
   ChatWindowInterface::readProperties( config );
 
-// Decomment should we need to read or save something again
-//  config->setGroup("Chat Window");
+  // Start saving our stuff
+  config->setGroup( "Chat Window" );
+
+  // Save the spell checking preference
+  toggleSpellCheck( config->readBoolEntry("UseSpellCheck", false) );
+
 }
 
 
@@ -1341,13 +1366,18 @@ void ChatWindow::saveProperties( KConfig *config )
   kdDebug() << "ChatWindow - Saving properties." << endl;
 #endif
 
-  // Also save ChatView's settings
-  chatView_->saveProperties( config );
-
+  // First save the general interface settings
   ChatWindowInterface::saveProperties( config );
 
-// Decomment should we need to read or save something again
-//   config->setGroup( "Chat Window" );
+
+  // Start saving our stuff
+  config->setGroup( "Chat Window" );
+
+  // Save the spell checking preference
+  config->writeEntry( "UseSpellCheck", chatView_->messageEdit_->checkSpellingEnabled() );
+
+  // Also save ChatView's settings
+  chatView_->saveProperties( config );
 }
 
 
@@ -1708,6 +1738,39 @@ void ChatWindow::toggleEmoticons(bool useEmoticons)
 
 
 
+// Called when the "use spell checking" action is called.
+void ChatWindow::toggleSpellCheck( bool useSpellCheck )
+{
+  // Don't crash if the chat view isn't available
+  if( KMESS_NULL(chatView_) ) return;
+
+#ifdef KMESSDEBUG_CHATWINDOW_GENERAL
+  kdDebug() << "ChatWindow::toggleSpellCheck() - Spell checking is now " << useSpellCheck << endl;
+#endif
+
+  // Access the spell checker
+  QSyntaxHighlighter       *syntax = chatView_->messageEdit_->syntaxHighlighter();
+  KDictSpellingHighlighter *spell  = dynamic_cast<KDictSpellingHighlighter*>( syntax );
+
+  if( spell )
+  {
+    // Put it to work
+    spell->setAutomatic( useSpellCheck );
+    spell->setActive( useSpellCheck );
+  }
+#ifdef KMESSDEBUG_CHATWINDOW_GENERAL
+  else
+  {
+    kdDebug() << "ChatWindow::toggleSpellCheck() - Spell checking unavailable." << endl;
+  }
+#endif
+
+  // Enable the spell check for the message editor
+  chatView_->messageEdit_->setCheckSpellingEnabled( useSpellCheck );
+}
+
+
+
 // Called when the "show sidebar" action is called.
 void ChatWindow::toggleSidebar()
 {
@@ -1955,8 +2018,8 @@ void ChatWindow::updateTypingMessage()
 // The user sent a new message
 void ChatWindow::userSentMessage()
 {
-  // If the emoticon sidebar is still visible, show contact bar again.
-  if( chatView_->sidebar_->currentItem() == standardEmoticonSidebar_ )
+  // If an emoticon sidebar is still visible, show the contact bar again.
+  if( chatView_->sidebar_->currentItem() != contactSidebar_ )
   {
     chatView_->sidebar_->setCurrentItem( contactSidebar_ );
   }
