@@ -63,6 +63,8 @@ class ChatWindow : public ChatWindowInterface
                       ~ChatWindow();
     // Disable the parts of the window which allow user interaction, to allow viewing conversations from disconnected accounts
     void               disable();
+    // Filter to catch window activation events
+    bool               eventFilter( QObject *obj, QEvent *event );
     // Initialize the object
     bool               initialize( QString handle );
     // Return the switchboard connection used by the chat window.
@@ -128,6 +130,8 @@ class ChatWindow : public ChatWindowInterface
     void               toggleEmoticons(bool useEmoticons);
     // Called when the "show sidebar" action is called.
     void               toggleSidebar();
+    // Called when the "use spell checking" action is called.
+    void               toggleSpellCheck( bool useSpellCheck );
 
   private: // Private methods
     // Check if the user enabled an auto-reply, and send it
