@@ -79,6 +79,8 @@ class ChatWindowInterface : public KMainWindow
     virtual void     toggleEmoticons(bool useEmoticons);
     // Called when the "show sidebar" action is called.
     virtual void     toggleSidebar();
+    // Called when the "use spell checking" action is called.
+    virtual void     toggleSpellCheck(bool useSpellCheck);
     // Send a nudge
     virtual void     slotSendNudge();
     // Send a file to a contact.
@@ -99,6 +101,8 @@ class ChatWindowInterface : public KMainWindow
     KToggleAction   *showStatusBar_, *showToolBar_;
     // The sidebar toggle
     KAction         *sidebarAction_;
+    // The spell checking toggle
+    KToggleAction   *spellCheckAction_;
 
 
   private: // Private methods
