@@ -554,9 +554,8 @@ void ContactFrame::updateStatusWidgets()
     iconName = "onthephone";
   }
 
-  label = contact_->getFriendlyName() + "  (" + statusIdentifier + ")";
-  statusLabel_->setText( label );
-
+  statusLabel_->setText( contact_->getFriendlyName() );
+  QToolTip::add( statusPixmapLabel_, i18n( "The contact is %1" ).arg( statusIdentifier ) );
   statusPixmapLabel_->setPixmap( loader->loadIcon( iconName, KIcon::User ) );
 
   // Update the detailed info widgets, if available
