@@ -39,11 +39,12 @@
 
 
 // The constructor
-Contact::Contact(QString handle, QString friendlyName, int lists, QString groupIds, QString guid)
+Contact::Contact(QString handle, QString friendlyName, int lists, QStringList groupIds, QString guid)
  : ContactBase(handle, friendlyName),
    allowed_(false),
    blocked_(false),
    friend_(false),
+   groupIds_(groupIds),
    guid_(guid),
    lastStatus_("FLN"),
    movingFrom_(""),
@@ -56,7 +57,6 @@ Contact::Contact(QString handle, QString friendlyName, int lists, QString groupI
   ASSERT( ! handle_.isEmpty() );
   ASSERT( ! friendlyName_.isEmpty() );
   ASSERT( lists != 0 );
-  ASSERT( groupIds.isEmpty() || groupIds.length() > 8 );
 #endif
 
   if(lists & MSN_LIST_FRIEND)  friend_  = true;
@@ -65,10 +65,6 @@ Contact::Contact(QString handle, QString friendlyName, int lists, QString groupI
   if(lists & MSN_LIST_REVERSE) reverse_ = true;
   if(lists & MSN_LIST_PENDING) pending_ = true;
 
-  if( groupIds.length() > 8 )  // make sure it's not an int or some other invalid parameter (should be a GUID)
-  {
-    groupIds_  = QStringList::split(",", groupIds);
-  }
 
   // The extension stores additional properties not found in
   // the official client/protocol, but only found in KMess.
