@@ -73,7 +73,7 @@ class Contact : public ContactBase
 
   public: // Public methods
     // The constructor
-                         Contact(QString handle, QString friendlyName, int lists, QString groupIds, QString guid);
+                         Contact(QString handle, QString friendlyName, int lists, QStringList groupIds, QString guid);
     // The destructor
                         ~Contact();
     // Add the groupID to the list of current groups
