@@ -33,6 +33,7 @@
 ContactExtension::ContactExtension(QString handle )
  : QObject(),
    alternativeName_(""),
+   clientName_(""),
    handle_(handle),
    notifyOnline_(true),
    pictureFile_(""),
@@ -90,6 +91,14 @@ const QString ContactExtension::getContactSoundPath() const
 
 
 
+// Read property of QString clientName_
+const QString ContactExtension::getClientName() const
+{
+  return clientName_;
+}
+
+
+
 // Read property of bool notifyOnline_
 bool ContactExtension::getNotifyOnline() const
 {
@@ -137,6 +146,8 @@ void ContactExtension::readProperties( KConfig *config )
     // We use the accessor function here because it handles the update, if required
     setUseAlternativeName  (  config->readBoolEntry("useAlternativeName",    false) );
 
+    clientName_            = config->readEntry("clientName",                    "");
+    
     notifyOnline_          =  config->readBoolEntry("notifyOnline",           true);
 
     pictureFile_           =      config->readEntry("pictureFile",              "");
@@ -164,6 +175,7 @@ void ContactExtension::saveProperties(KConfig *config)
   if( notifyOnline_
       && ! useAlternativeName_
       && alternativeName_ == ""
+      && clientName_ == ""
       && pictureFile_ == ""
       && soundFile_ == "" )
   {
@@ -189,6 +201,7 @@ void ContactExtension::saveProperties(KConfig *config)
 
   config->writeEntry( "useAlternativeName",      useAlternativeName_       );
   config->writeEntry( "alternativeName",         alternativeName_          );
+  config->writeEntry( "clientName",              clientName_               );
   config->writeEntry( "notifyOnline",            notifyOnline_             );
   config->writeEntry( "pictureFile",             pictureFile_              );
   config->writeEntry( "soundFile",               soundFile_                );
@@ -209,6 +222,13 @@ void ContactExtension::setAlternativeName( const QString& _newVal )
 
 
 
+// Write property of QString clientName_
+void ContactExtension::setClientName( const QString& _newVal ) 
+{
+  clientName_ = _newVal;
+}
+
+
 
 // Write property of QString  pictureFile_.
 void ContactExtension::setContactPicturePath( const QString & _newVal)
