@@ -55,6 +55,8 @@ class ContactExtension : public QObject
     const QString          getContactPicturePath() const;
     // Read property of QString soundFile_.
     const QString          getContactSoundPath() const;
+    // Read property of QString clientName_
+    const QString          getClientName() const;
     // Read property of bool notifyOnline_
     bool                   getNotifyOnline() const;
     // Read property of bool useAlternativeName_.
@@ -65,6 +67,8 @@ class ContactExtension : public QObject
     void                   saveProperties(KConfig *config);
     // Write property of QString alternativeName_.
     void                   setAlternativeName( const QString& _newVal );
+    //Write property of QString clientname_.
+    void                   setClientName ( const QString& _newVal );
     // Write property of QString pictureFile_.
     void                   setContactPicturePath( const QString& _newVal );
     // Write property of QString soundFile_.
@@ -78,6 +82,8 @@ class ContactExtension : public QObject
   private: // Private attributes
     // The alternative name
     QString                alternativeName_;
+    // The client name used by the user
+    QString                clientName_;
     // The contact's handle (ie email)
     QString                handle_;
     // Whether or not to notify online/offline status
