@@ -85,7 +85,7 @@ ContactList::~ContactList()
 
 
 // Add a contact to the contact list
-Contact * ContactList::addContact( QString handle, QString friendlyName, int lists, QString groupIds, QString guid )
+Contact * ContactList::addContact( QString handle, QString friendlyName, int lists, QStringList groupIds, QString guid )
 {
 #ifdef KMESSDEBUG_CONTACTLIST_GENERAL
   kdDebug() << "ContactList::addContact " << handle << endl;
