@@ -61,7 +61,7 @@ class ContactList : public QObject
     // The destructor
                         ~ContactList();
     // Add a contact to the contact list
-    Contact *            addContact( QString handle, QString friendlyName, int lists, QString groupIds, QString guid );
+    Contact *            addContact( QString handle, QString friendlyName, int lists, QStringList groupIds, QString guid );
     // Add a group to the contact list
     Group *              addGroup( QString groupId, QString groupName );
     // Change a contact's status (and update the friendly name)
