@@ -131,7 +131,8 @@ void ContactListViewItem::construct()
   connect(contact_, SIGNAL(changedStatus()),                  this, SLOT(slotUpdateStatus())                  );
   connect(contact_, SIGNAL(changedList(Contact*)),            this, SLOT(slotUpdateStatus())                  );
   connect(contact_, SIGNAL(changedPersonalMessage(Contact*)), this, SLOT(slotUpdatePersonalStatus())          );
-  // changedList() is not connected to slotUpdateVisability because the "blocked" icon should also appear.
+  connect(contact_, SIGNAL(changedPicture()),                 this, SLOT(slotUpdatePicture())                 );
+  // changedList() is not connected to slotUpdateVisibility because the "blocked" icon should also appear.
 
   // Call the event manually this time, to update the appearance.
   slotUpdateStatus();
@@ -181,6 +182,38 @@ QString ContactListViewItem::getToolTipText() const
   // Add handle on new line
   tipText += "<br>" + handle;
 
+  // Add client identifier
+  // @note If you want to add new client identifiers here's the right place
+  QString clientIdentifier = contact_->getExtension()->getClientName(); // Contains the client identifier with full information
+  if ( ! clientIdentifier.isEmpty() )
+  {
+    QString clientName;
+
+    if ( clientIdentifier.find("KMess") != -1 )
+    {
+      clientName = "KMess";
+    }
+    else if ( clientIdentifier.find("Mercury") != -1 )
+    {
+      clientName = "Mercury";
+    }
+    else if ( clientIdentifier.find("Kopete") != -1 )
+    {
+      clientName = "Kopete";
+    }
+    else if ( clientIdentifier.find("Purple") != -1 )
+    {
+      clientName = "Pidgin";
+    }
+    else
+    {
+      // Just report as-is if it's not been identified
+      clientName = clientIdentifier;
+    }
+
+    tipText += "<br>" + i18n("Client: %1").arg(clientName);
+  }
+
   // Return
   tipText += "</qt>";
   return tipText;
@@ -363,7 +396,7 @@ void ContactListViewItem::slotUpdateStatus()
 
 
   // Update vars
-  iconTag_ = "<img align=left src=\"" + iconPath + "\">";
+  iconTag_ = "<img valign=\"bottomline\" src=\"" + iconPath + "\">";
 
 
   // Set the sort text
@@ -382,6 +415,12 @@ void ContactListViewItem::slotUpdateStatus()
 
 
 
+// Update the display picture of the contact
+void ContactListViewItem::slotUpdatePicture()
+{
+  updateItemText();
+}
+
 // Update the visibility of the contact
 void ContactListViewItem::slotUpdateVisiblity()
 {
@@ -416,6 +455,7 @@ void ContactListViewItem::slotUpdateVisiblity()
       setVisible( currentAccount->getShowRemovedContacts() );
     }
   }
+  updateItemText();
 }
 
 
@@ -423,48 +463,64 @@ void ContactListViewItem::slotUpdateVisiblity()
 // Update the item's text
 void ContactListViewItem::updateItemText()
 {
-  QString newIdentifier;
-  QString newText;
-  QString sortText;
+   QString newIdentifier;
+   QString friendlyName;
+   QString newText;
+   QString sortText;
+   QString contactPic = contact_->getContactPicturePath();
+   QString picTag = "<img src=\"" + contactPic + "\" align=\"left\" valign=\"bottomline\" width=\"42\" height=\"42\">";
 
-  // Parse the emoticons
-  newIdentifier = QStyleSheet::escape( contact_->getFriendlyName() );
-  emoticons_->parseEmoticons(newIdentifier, true);
+   // Parse the emoticons
+   newIdentifier = QStyleSheet::escape( contact_->getFriendlyName() );
+   emoticons_->parseEmoticons(newIdentifier, true);
 
-  // Icon
-  newText = iconTag_ + " ";
+   // Display the nickname in italics if the contact has deleted us from its list.
+   if( ! contact_->isReverse() )
+   {
+     friendlyName = "<i>" + newIdentifier + "</i>";
+   }
+   else
+   {
+     friendlyName = newIdentifier;
+   }
 
-  // Reverse list?
-  bool contactRemovedUser = ( ! contact_->isReverse() );
+   // Build the HTML code for the Contact List visualizations
+   if( ! contactPic.isEmpty() &&
+       CurrentAccount::instance()->getShowListPictures() )
+   {
+     // new visualization (Display Pictures)
+     newText = picTag + " " + iconTag_ + " " + friendlyName;
 
-  // Start italics?
-  if( contactRemovedUser )
-  {
-    newText += "<i>";
-  }
+     // Status identifier
+     if( ! statusIdentifier_.isEmpty() )
+     {
+       newText += "  (" + statusIdentifier_ + ")";
+     }
 
-  // friendly name
-  newText += newIdentifier;
+     // Add personal status message (already HTML escaped)
+     if( ! personalStatus_.isEmpty() )
+     {
+       newText += "<br>&nbsp;" + personalStatus_;
+     }
+   }
+   else
+   {
+     // old visualization (only status icon)
+     newText = iconTag_ + " " + friendlyName;
 
-  // End italics?
-  if( contactRemovedUser )
-  {
-    newText += "</i>";
-  }
-
-  // Add personal status message (already HTML escaped)
-  if( ! personalStatus_.isEmpty() )
-  {
-    // NOTE: MSN Adds a "-" as seperator here, but smaller font + color makes it cleaner.
-    newText += " " + personalStatus_;
-  }
-
-  // Status identifier
-  if( ! statusIdentifier_.isEmpty() )
-  {
-    newText += "  (" + statusIdentifier_ + ")";
-  }
+     // Add personal status message (already HTML escaped)
+     if( ! personalStatus_.isEmpty() )
+     {
+       // NOTE: MSN Adds a "-" as seperator here, but smaller font + color makes it cleaner.
+       newText += " " + personalStatus_;
+     }
 
+     // Status identifier
+     if( ! statusIdentifier_.isEmpty() )
+     {
+       newText += " (" + statusIdentifier_ + ")";
+     }
+   }
 
   setText( newText );
 }
