@@ -74,6 +74,8 @@ class ContactListViewItem : public QObject, public KMessListViewItem
     void                 slotUpdatePersonalStatus();
     // Update the status icon of the contact
     void                 slotUpdateStatus();
+    // Update the display picture of the contact
+    void                 slotUpdatePicture();
     // Update the visibility of the contact
     void                 slotUpdateVisiblity();
 
