@@ -695,6 +695,13 @@ NetworkWindow::NetworkWindow(QWidget *parent, const char *name)
       ASSERT( posFound );
     #endif
 
+    // If the data size is completely wrong, we're dealing with partially sent data here,
+    // caused by DirectConnectionBase::slotSocketReadyWrite().
+    if( dataSize > 3000 )
+    {
+      return "<font color=gray>(" + QString::number( message.size() ) + " bytes of binary data, flushed afterwards, can't parse)</font>";
+    }
+
     // Show header information
     logMessage += formatRawData(incoming, message, headerStart, 48, 16);
 
@@ -761,7 +768,10 @@ NetworkWindow::NetworkWindow(QWidget *parent, const char *name)
     logMessage += (incoming? "#4747C2" : "#CC334D");
     logMessage += ">";
 
-    for(int i = 0; i < length; i++)
+    // If length field is corrupt (e.g. 432712149, avoid looping though 4GB of memory..
+    int safeLength = QMIN( (uint) length, message.size() - start );
+
+    for(int i = 0; i < safeLength; i++)
     {
       // Add spacers between ints, make it span multiple rows.
       if( i > 0 )
