@@ -29,6 +29,7 @@
 #include <krun.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
+#include <ksocks.h>
 
 #if KDE_IS_VERSION(3,2,0)
 #include <kinputdialog.h>
@@ -138,7 +139,6 @@ KMess::~KMess()
   delete notificationContactStatus_;
   delete notificationNewEmail_;
   delete nowListeningClient_;
-  delete systemTrayWidget_;
   delete msnNotificationConnection_;
   CurrentAccount::destroy();
   TransferWindow::destroy();
@@ -444,6 +444,8 @@ void KMess::changeStatus(const QString &statusName)
   AwayMessageDialog *awayMessageDialog;
   QString            awayMessage;
 
+  isIdleForced_ = false;
+
 #ifdef KMESSDEBUG_KMESS
   kdDebug() << "Selected status " << statusName << endl;
 #endif
@@ -469,6 +471,11 @@ void KMess::changeStatus(const QString &statusName)
     }
     delete awayMessageDialog;
   }
+  else if ( statusName == i18n("Idle") )
+  { // Change status to IDLE
+    newStatus = "IDL";
+    isIdleForced_ = true;
+  }
   else if ( statusName == i18n("Be Right Back") )
   { // Change status to BE RIGHT BACK
     newStatus = "BRB";
@@ -591,21 +598,25 @@ void KMess::changedStatus( Account *account )
       item = 2;
     }
   }
+  else if ( newStatus == "IDL" )
+  { // Change status to IDLE
+    item = 3;
+  }
   else if ( newStatus == "BRB" )
   { // Change status to BE RIGHT BACK
-    item = 3;
+    item = 4;
   }
   else if ( newStatus == "BSY" )
   { // Change status to BUSY
-    item = 4;
+    item = 5;
   }
   else if ( newStatus == "HDN" )
   { // Change status to INVISIBLE
-    item = 7;
+    item = 8;
   }
   else if ( newStatus == "LUN" )
   { // Change status to OUT TO LUNCH
-    item = 5;
+    item = 6;
   }
   else if ( newStatus == "NLN" )
   { // Change status to ONLINE
@@ -613,7 +624,7 @@ void KMess::changedStatus( Account *account )
   }
   else if ( newStatus == "PHN" )
   { // Change status to ON THE PHONE
-    item = 6;
+    item = 7;
   }
 
 #ifdef KMESSDEBUG_KMESS
@@ -886,6 +897,7 @@ void KMess::connected()
   showAllowedAction_->setChecked( currentAccount_->getShowAllowedContacts() );
   showOfflineAction_->setChecked( currentAccount_->getShowOfflineContacts() );
   showRemovedAction_->setChecked( currentAccount_->getShowRemovedContacts() );
+  showPicturesAction_->setChecked( currentAccount_->getShowListPictures()   );
   if ( currentAccount_->getShowContactsByGroup() )
   {
     viewMode_->setCurrentItem( 0 );
@@ -1306,11 +1318,6 @@ bool KMess::initialize()
     kdDebug() << "KMess - Couldn't initialize the KMessView widget." << endl;
     return false;
   }
-  if ( !initSystemTrayWidget() )
-  {
-    kdDebug() << "KMess - Couldn't initialize the system tray widget." << endl;
-    return false;
-  }
   if ( !initNotifications() )
   {
     kdDebug() << "KMess - Couldn't initialize the notifications." << endl;
@@ -1608,6 +1615,30 @@ bool KMess::initMsnNotificationConnection()
   connect( msnNotificationConnection_, SIGNAL(              statusMessage(QString, KMessInterface::ConnectionStatus)   ),   // Display a status message
            this,                       SLOT  (              statusMessage(QString, KMessInterface::ConnectionStatus)   ) );
 
+  // Check the current Socks implementation.
+  // Some implementation do not support async connections,
+  // which will cauase KMess to freeze for 2 minutes if the connection can't be made.
+#ifdef KMESSTEST
+  ASSERT( KSocks::activated() );
+#endif
+
+  if( KSocks::self()->hasSocks()
+  &&  KSocks::self()->usingSocks()
+  && ! KSocks::self()->hasWorkingAsyncConnect() )
+  {
+    // Always show warning at the console.
+    kdWarning() << "Your SOCKS implementation does not support asynchronous connections. Please disable SOCKS support in the KDE Control Center if you don't have to use a proxy server." << endl;
+
+    // Show the message in the GUI as well.
+    // Allow to user to choose "don't show this message again", in case he/she can't fix it.
+    KMessageBox::information( this, i18n( "<qt><p>Your SOCKS implementation does not support asynchronous connections.</p>"
+                                          "<p>This could cause KMess to freeze occasionally when it initiates a direct connection for file or picture transfers.</p>"
+                                          "<p>Please disable SOCKS support in the KDE Control Center if you don't have to use a proxy server to connect to the Internet.</p>"
+                                          "</qt>" ),
+                                    i18n( "Error in SOCKS implementation" ),
+                                    "socksWithoutAsyncConnect" );
+  }
+
   return true;
 }
 
@@ -1734,48 +1765,6 @@ bool KMess::initNowListening()
 }
 
 
-// Initialize the system tray widget
-bool KMess::initSystemTrayWidget()
-{
-  bool initialized;
-
-  // Create the widget
-  systemTrayWidget_ = new SystemTrayWidget( this, "systemtraywidget" ) ;
-  if ( systemTrayWidget_ == 0 )
-  {
-    kdDebug() << "KMess - Couldn't create system tray widget." << endl;
-    return false;
-  }
-
-  // Initialize the widget
-  initialized = systemTrayWidget_->initialize();
-  if ( !initialized )
-  {
-    kdDebug() << "KMess - Couldn't initialize system tray widget." << endl;
-    return false;
-  }
-
-  // Plug some of the menu actions into the system tray widget's menu.
-  connectActionMenu_-> plug( systemTrayWidget_->menu() );
-  disconnect_->        plug( systemTrayWidget_->menu() );
-  systemTrayWidget_->  menu()->insertSeparator();
-  status_->            plug( systemTrayWidget_->menu() );
-  systemTrayWidget_->  menu()->insertSeparator();
-  settingsActionMenu_->plug( systemTrayWidget_->menu() );
-
-  // Make the connections for the system tray widget
-  connect( systemTrayWidget_, SIGNAL( quitSelected() ),
-           this,              SLOT  (     menuQuit() ) );
-
-  systemTrayWidget_->show();
-#ifdef KMESSTEST
-  ASSERT( systemTrayWidget_ != 0 );
-  ASSERT( systemTrayWidget_->isVisible() );
-#endif
-  return true;
-}
-
-
 
 // Validate a contact email
 bool KMess::isValidEmail( QString email )
@@ -1826,7 +1815,7 @@ void KMess::saveProperties(KConfig *config)
   }
 #endif
 
-  config = kapp->config();   // Hack, but it seams to work
+  config = kapp->config();   // Hack, but it seems to work
   KMessInterface::saveProperties(config);
 
 #ifdef KMESSDEBUG_KMESS
@@ -1984,6 +1973,14 @@ void KMess::shutDown()
 
 
 
+// The "show display pictures" menu item has been toggled.
+void KMess::toggleDisplayPictures(bool show)
+{
+  currentAccount_->setShowListPictures( show );
+}
+
+
+
 // The "show allowed contacts" menu item has been toggled.
 void KMess::toggleShowAllowed(bool show)
 {
@@ -2027,6 +2024,7 @@ void KMess::userIsIdle()
 #endif
       // Request a status change to "IDL"
       msnNotificationConnection_->changeStatus("IDL");
+      isIdleForced_ = false;
     }
   }
 #ifdef KMESSDEBUG_KMESS
@@ -2047,8 +2045,8 @@ void KMess::userIsNotIdle()
 #ifdef KMESSDEBUG_KMESS
     kdDebug() << "KM:   User is no longer idle, current status is " << currentAccount_->getStatus() << endl;
 #endif
-    // Only change the state if the user is currently set as idle
-    if ( currentAccount_->getStatus() == "IDL" )
+    // Only change the state if the user is currently set as idle AND the idle status was not forced by the user
+    if ( currentAccount_->getStatus() == "IDL" && ! isIdleForced_ )
     {
 #ifdef KMESSDEBUG_KMESS
       kdDebug() << "KM:   Change status to NLN" << endl;
