@@ -46,7 +46,6 @@ class InitialView;
 class KMessTest;
 class KMessView;
 class MsnNotificationConnection;
-class SystemTrayWidget;
 class NowListeningClient;
 
 /**
@@ -107,8 +106,6 @@ class KMess : public KMessInterface
     bool               initNotifications();
     // Initialize the now listening support.
     bool               initNowListening();
-    // Initialize the system tray widget
-    bool               initSystemTrayWidget();
     // Validate a contact email
     bool               isValidEmail( QString email );
     // Set the caption
@@ -179,6 +176,8 @@ class KMess : public KMessInterface
     void               showUserProfile();
     // We're about to shutdown, apparently
     void               shutDown();
+    // The "show display pictures" menu item has been toggled.
+    void               toggleDisplayPictures(bool show);
     // The "show allowed contacts" menu item has been toggled.
     void               toggleShowAllowed(bool show);
     // The "show offline contacts" menu item has been toggled.
@@ -217,14 +216,14 @@ class KMess : public KMessInterface
     bool               initialized_;
     // The initial login view widget
     InitialView       *initialView_;
+    // Whether the user has forced the Idle status or if it's been changed automatically
+    bool               isIdleForced_;
     // The now listening client
     NowListeningClient* nowListeningClient_;
     // The connection to the msn notification server
     MsnNotificationConnection *msnNotificationConnection_;
     // The menu items of the settings menu
     QDict<AccountAction> settingsMenuItems_;
-    // The system tray widget
-    SystemTrayWidget  *systemTrayWidget_;
     // The main view widget
     KMessView         *view_;
 };
