@@ -41,6 +41,7 @@
 
 #include "kmessdebug.h"
 #include "kmessapplication.h"
+#include "systemtraywidget.h"
 
 
 // The constructor
@@ -57,6 +58,8 @@ KMessInterface::KMessInterface(QWidget *parent, const char *name )
 // The destructor
 KMessInterface::~KMessInterface()
 {
+  delete systemTrayWidget_;
+
 #ifdef KMESSDEBUG_KMESSINTERFACE
   kdDebug() << "DESTROYED KMessInterface " << endl;
 #endif
@@ -188,6 +191,7 @@ void KMessInterface::createConnectMenu()
   statuses << i18n("Online")
            << i18n("Away")
            << i18n("Away with auto-reply")
+           << i18n("Idle")
            << i18n("Be Right Back")
            << i18n("Busy")
            << i18n("Out to Lunch")
@@ -271,6 +275,7 @@ void KMessInterface::createViewMenu()
   showAllowedAction_ = new KToggleAction( i18n("Show &Allowed Contacts"), 0, KShortcut(), this, "allowed");
   showOfflineAction_ = new KToggleAction( i18n("Show &Offline Contacts"), 0, KShortcut(), this, "offline");
   showRemovedAction_ = new KToggleAction( i18n("Show &Removed Contacts"), 0, KShortcut(), this, "removed");
+  showPicturesAction_= new KToggleAction( i18n("Show &Display Pictures"), 0, KShortcut(), this, "showpics");
 
 #ifdef KMESS_NETWORK_WINDOW
   showNetworkAction_ = new KAction(i18n("Show &Network Window"), "network_local", 0,
@@ -293,16 +298,22 @@ void KMessInterface::createViewMenu()
   connect( showOfflineAction_, SIGNAL( toggled(bool) ), this, SLOT( toggleShowOffline(bool) ) );
   connect( showRemovedAction_, SIGNAL( toggled(bool) ), this, SLOT( toggleShowRemoved(bool) ) );
 
+  // Connect "Show Display Pictures" setting
+  connect( showPicturesAction_, SIGNAL( toggled(bool) ), this, SLOT( toggleDisplayPictures(bool) ) );
+
   // Plug the items into "view"
-  showAllowedAction_ ->plug( viewMenu_ );
-  showRemovedAction_ ->plug( viewMenu_ );
-  showOfflineAction_ ->plug( viewMenu_ );
-  viewMode_          ->plug( viewMenu_ );
-  viewMenu_          ->insertSeparator();
-  showTransferAction_->plug( viewMenu_ );
-  viewMenu_          ->insertSeparator();
-  showToolBar_       ->plug( viewMenu_ );
-  showStatusBar_     ->plug( viewMenu_ );
+  showAllowedAction_  ->plug( viewMenu_ );
+  showRemovedAction_  ->plug( viewMenu_ );
+  showOfflineAction_  ->plug( viewMenu_ );
+  viewMenu_           ->insertSeparator();
+  showPicturesAction_ ->plug( viewMenu_ );
+  viewMenu_           ->insertSeparator();
+  viewMode_           ->plug( viewMenu_ );
+  viewMenu_           ->insertSeparator();
+  showTransferAction_ ->plug( viewMenu_ );
+  viewMenu_           ->insertSeparator();
+  showToolBar_        ->plug( viewMenu_ );
+  showStatusBar_      ->plug( viewMenu_ );
 
 #ifdef KMESS_NETWORK_WINDOW
   viewMenu_->insertSeparator();
@@ -352,6 +363,7 @@ void KMessInterface::enableMenus(bool connected)
   showAllowedAction_->setEnabled( connected );
   showOfflineAction_->setEnabled( connected );
   showRemovedAction_->setEnabled( connected );
+  showPicturesAction_->setEnabled( connected );
   showProfile_->      setEnabled( connected );
   viewMode_->         setEnabled( connected );
   // showNetworkAction should ALWAYS be enabled!
@@ -396,6 +408,12 @@ bool KMessInterface::initialize()
   // Create the menus
   createMenus();
 
+  if ( ! initSystemTrayWidget() )
+  {
+    kdDebug() << "KMess - Couldn't initialize the system tray widget." << endl;
+    return false;
+  }
+
 #ifdef KMESSDEBUG_KMESSINTERFACE
   kdDebug() << "KMessInterface - initialized" << endl;
 #endif
@@ -403,6 +421,48 @@ bool KMessInterface::initialize()
 }
 
 
+// Initialize the system tray widget
+bool KMessInterface::initSystemTrayWidget()
+{
+  bool initialized;
+
+  // Create the widget
+  systemTrayWidget_ = new SystemTrayWidget( this, "systemtraywidget" ) ;
+  if ( systemTrayWidget_ == 0 )
+  {
+    kdDebug() << "KMessInterface - Couldn't create system tray widget." << endl;
+    return false;
+  }
+
+  // Initialize the widget
+  initialized = systemTrayWidget_->initialize();
+  if ( !initialized )
+  {
+    kdDebug() << "KMessInterface - Couldn't initialize system tray widget." << endl;
+    return false;
+  }
+
+  // Plug some of the menu actions into the system tray widget's menu.
+  connectActionMenu_-> plug( systemTrayWidget_->menu() );
+  disconnect_->        plug( systemTrayWidget_->menu() );
+  systemTrayWidget_->  menu()->insertSeparator();
+  status_->            plug( systemTrayWidget_->menu() );
+  systemTrayWidget_->  menu()->insertSeparator();
+  settingsActionMenu_->plug( systemTrayWidget_->menu() );
+
+  // Make the connections for the system tray widget
+  connect( systemTrayWidget_, SIGNAL( quitSelected() ),
+           this,              SLOT  (     menuQuit() ) );
+
+  systemTrayWidget_->show();
+#ifdef KMESSTEST
+  ASSERT( systemTrayWidget_ != 0 );
+  ASSERT( systemTrayWidget_->isVisible() );
+#endif
+  return true;
+}
+
+
 // Close has been selected from the menu.
 void KMessInterface::menuClose()
 {
@@ -470,14 +530,9 @@ bool KMessInterface::queryClose()
     applicationClosing();
     return true;
   }
-  else
-  {
-    // Tell that KMess is still visible in the tray
-    KMessageBox::information( this,
-                              i18n( "Closing the main window will keep KMess running in the "
-                                    "system tray. Use 'Quit' from the 'File' menu to quit the application." ),
-                              i18n( "Docking in System Tray" ), "hideOnCloseInfo" );
-  }
+
+  // Tell that KMess is still visible in the tray
+  systemTrayWidget_->displayCloseMessage();
 
 #ifdef KMESSDEBUG_KMESSINTERFACE
   kdDebug() << "KMessInterface::queryClose: Rejecting quit request, hiding window" << endl;
@@ -657,6 +712,14 @@ void KMessInterface::statusMessage( QString message, ConnectionStatus connectSta
 
 
 
+// The "show display pictures" menu item has been toggled.
+void KMessInterface::toggleDisplayPictures(bool /*show*/)
+{
+  kdDebug() << "toggleDisplayPictures not implemented" << endl;
+}
+
+
+
 // The "show allowed contacts" menu item has been toggled.
 void KMessInterface::toggleShowAllowed(bool /*show*/)
 {
