@@ -34,6 +34,7 @@ class KMessTest;
 class KPopupMenu;
 class KSelectAction;
 class KToggleAction;
+class SystemTrayWidget;
 
 /**
  * @brief User interface of the KMess class.
@@ -99,6 +100,8 @@ class KMessInterface : public KMainWindow
     virtual void     showUserProfile();
     // Change the status bar message.
     virtual void     statusMessage(QString message, KMessInterface::ConnectionStatus connectStatus = TYPE_ERROR );
+    // The "show display pictures" menu item has been toggled.
+    virtual void     toggleDisplayPictures(bool show);
     // The "show allowed contacts" menu item has been toggled.
     virtual void     toggleShowAllowed(bool show);
     // The "show offline contacts" menu item has been toggled.
@@ -120,10 +123,14 @@ class KMessInterface : public KMainWindow
     KToggleAction   *showAllowedAction_, *showOfflineAction_, *showRemovedAction_;
     // Show the network window
     KAction         *showNetworkAction_;
+    // Toggle actions for showing display pictures in contact list.
+    KToggleAction *showPicturesAction_;
     // Show the transfer manager
     KAction         *showTransferAction_;
     // The select action for the user's status
     KSelectAction   *status_;
+    // The system tray widget
+    SystemTrayWidget *systemTrayWidget_;
     // The menu for selecting the view mode.
     KSelectAction   *viewMode_;
 
@@ -138,6 +145,8 @@ class KMessInterface : public KMainWindow
     void             createMenus();
     // Create the "View" menu
     void             createViewMenu();
+    // Initialize the system tray widget
+    bool             initSystemTrayWidget();
     // Reject quitting unless the quit menu was pressed
     bool             queryExit();
     // Tell the user that KMess hides in the systray
