@@ -497,7 +497,7 @@ bool KMessView::eventFilter(QObject *obj, QEvent *event)
       // Personal status mesage got the focus
       personalMessageInput_->setBackgroundColor( Qt::white );
       //personalMessageInput_->setFrameShape( QLineEdit::StyledPanel );
-  
+
       // Clear if there is no status message, but a placeholder label
       if( currentAccount_->getPersonalMessage().isEmpty() )
       {
@@ -590,7 +590,7 @@ bool KMessView::initContactListView()
   contactListView_->header()->hide();
   contactListView_->setStaticBackground(true);   // Workarround for the smudge
 //  contactListView_->setRootIsDecorated(true);
-//  contactListView_->setPaletteForegroundColor( QColor( "#000000" ) );
+  contactListView_->setPaletteForegroundColor( Qt::black );
 
 
   // Set a background pixmap
@@ -1128,12 +1128,12 @@ void KMessView::slotContextMenu(QListViewItem *item, const QPoint &point, int /*
 
     // Only if the contact is not in the 'Implicit' group (group 0) or there is only one group;
     // (this means it will be the fifth ('Implicit', Online, Offline, Allowed, Removed);
-    if(contact->getGroupIds()[0] == 0 ) 
+    if(contact->getGroupIds()[0] == 0 )
     {
       copyContactToGroup_ ->setEnabled( false );
     }
     else if( contact->getGroupIds()[0] != 0 &&
-             currentAccount_->getContactList()->getGroupList().count() == 5 ) 
+             currentAccount_->getContactList()->getGroupList().count() == 5 )
     {
       copyContactToGroup_ ->setEnabled( false );
       moveContactToGroup_ ->setEnabled( false );
@@ -1737,7 +1737,7 @@ void KMessView::slotUpdateNoEmails()
 // Update the user's status.
 void KMessView::slotUpdateUserStatus()
 {
- 
+
   QString          friendlyName, status;
   QString          statusIdentifier;
   QString          image;
@@ -1831,7 +1831,7 @@ KMessView::ToolTip::ToolTip(KMessView *kmessView, QToolTipGroup *group)
 
 KMessView::ToolTip::~ToolTip()
 {
-  
+
 }
 
 
