@@ -112,28 +112,10 @@ MsnConnection::~MsnConnection()
 void MsnConnection::connectionClosed(int state)
 {
 #ifdef KMESSDEBUG_CONNECTION_SOCKET
-  kdDebug() << "MsnConnection::connectionClosed() - state is " << state << endl;
+  kdDebug() << name() << "::connectionClosed() - state is " << state << endl;
 #endif
 
-/*
-// TODO: test for for KMess 1.6
-
-  // Notify
-  if( ! disconnected_ && ! ( state & KBufferedIO::closedNow ) )
-  {
-    // First disable pings, KMessageBox blocks here but it's private event loop would keep processing more ping timeouts.
-    setSendPings(false);
-
-    if( state & KBufferedIO::involuntary )
-    {
-      KMessageBox::error( 0, i18n("The remote server has closed the connection.") );
-    }
-
-    // Close connection, updates GUI.
-    closeConnection();
-    disconnectFromServer(false);
-  }
-*/
+  // Manage the disconnection in the subclasses, when needed.
 }
 
 
@@ -767,7 +749,7 @@ void MsnConnection::sendPing()
   // Assume the connection was lost when 3 pings are missed.
   if ( missedPings_ == 3 )
   {
-    KMessageBox::error( 0, i18n("The connection to the server was lost.") );
+    KMessageBox::queuedMessageBox( 0, KMessageBox::Error, i18n("The connection to the server was lost.") );
     closeConnection();
     disconnectFromServer(false);
   }
@@ -818,9 +800,7 @@ void MsnConnection::writeData(const QString& data)
     {
       kdWarning() << name() << "::writeData() - Attempting to write data to a disconnected socket, closing socket." << endl;
 
-      // First disable pings, KMessageBox blocks here but it's private event loop would keep processing more ping timeouts.
-      setSendPings(false);
-      KMessageBox::error( 0, i18n("The remote server has closed the connection.") );
+      KMessageBox::queuedMessageBox( 0, KMessageBox::Error, i18n("The remote server has closed the connection.") );
 
       // Close connection, updates GUI.
       closeConnection();
