@@ -31,7 +31,8 @@
 #include <qfile.h>
 
 #include "../chat/chatmessage.h"
-#include "../contact/contactbase.h"
+#include "../contact/contact.h"
+#include "../contact/contactlist.h"
 #include "../contact/invitedcontact.h"  // for cast
 #include "../currentaccount.h"
 #include "../kmessapplication.h"
@@ -1279,7 +1280,26 @@ void MsnSwitchboardConnection::parseMessage(const QStringList& command, const Mi
   {
     // This is a message exchanged by a lot of third party clients.
 #ifdef KMESSDEBUG_SWITCHBOARD_GENERAL
-    kdDebug() << "Switchboard: Got third-party client info message. (message dump follows)\n" << message.getMessage().data() << endl;
+    kdDebug() << "Switchboard: Got third-party client info message. (message dump follows)" << endl
+              << message.getMessage().data() << endl;
+
+    // Retrieve client identifier from message and store in Contact Extension
+    QString messageData = message.getMessage().data();
+    int start = messageData.find("Client-Name: ");
+    int end = messageData.find("\r\n", start);
+
+    // cut message parts we don't need
+    messageData = messageData.mid(start, end-start);
+    messageData = messageData.section(' ', 1);
+
+    // store in contact extension
+    Contact *contact = currentAccount_->getContactList()->getContactByHandle( contactHandle );
+    if( contact != 0 )
+    {
+      contact->getExtension()->setClientName( messageData );
+    }
+
+    // An example of an x-clientcaps message:
     // Client-Name: Client-Name/Version-Major.Version-Minor
     // Chat-Logging: Y (Nonsecure logging is enabled), S (log is encrypted), N (client is not logging conversation)
 #endif
@@ -1503,7 +1523,7 @@ void MsnSwitchboardConnection::sendClientCaps()
   MimeMessage message;
   message.addField("MIME-Version", "1.0");
   message.addField("Content-Type", "text/x-clientcaps");
-  message.setBody( "Client-Name: KMess " + kapp->aboutData()->version() + "\r\n" );
+  message.setBody( "Client-Name: KMess/" + kapp->aboutData()->version() + "\r\n" );
   sendMimeMessageWhenReady( ACK_NONE, message );
 }
 
