@@ -37,11 +37,13 @@ class SystemTrayWidget : public KSystemTray
 
   public:
     // The constructor
-  	                 SystemTrayWidget(QWidget *parent=0, const char *name=0);
+                     SystemTrayWidget(QWidget *parent=0, const char *name=0);
     // The destructor
-  	                ~SystemTrayWidget();
+                    ~SystemTrayWidget();
     // Initialize the class
     bool             initialize();
+    // Display a customized close window with a screenshot of the app's tray icon
+    void             displayCloseMessage( QString fileMenu = QString::null );
     // Return the context menu
     KPopupMenu      *menu() const;
 
