@@ -16,6 +16,7 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "../config.h"
 #include "xautolock.h"
 
 #include <stdlib.h>
@@ -36,6 +37,8 @@
 
 #include <qtimer.h>
 
+#include <dcopclient.h>
+#include <kapplication.h>
 #include <kdebug.h>
 
 // Construct
@@ -48,8 +51,6 @@ XAutoLock::XAutoLock()
     mitInfo_( 0 ),
     triggerTime_( 0 )
 {
-  int dummy;
-
   timer_ = new QTimer( this, "idleCheckTimer" );
   timer_->stop();
 
@@ -57,7 +58,8 @@ XAutoLock::XAutoLock()
            this,     SLOT( checkIdle() ) );
 
   #ifdef HAVE_XSCREENSAVER
-    mitAvailable_ = XScreenSaverQueryExtension(qt_xdisplay(), &dummy, &dummy) != 0;
+    int dummy;
+    mitAvailable_ = ( XScreenSaverQueryExtension( qt_xdisplay(), &dummy, &dummy ) != 0 );
   #endif
 }
 
@@ -67,6 +69,7 @@ XAutoLock::~XAutoLock()
 {
   emit activity();
   timer_->stop();
+
   delete mitInfo_;
   delete timer_;
 }
@@ -79,21 +82,26 @@ void XAutoLock::checkIdle()
 
   now = time( 0 );
 
-  if ( abs( lastCheck_ - now ) > 120 )
+  if( abs( lastCheck_ - now ) > 120 )
   {
-    /*
-      Whoah, two minutes since we were last called?  Something strange is happenning...
-    */
+    // Whoah, two minutes since we were last called?  Something strange is happening...
     resetTimer();
   }
 
   lastCheck_ = now;
 
-  if ( mitAvailable_ )
+  // Check for screen saver or locker presence. If it's on, we're idle
+  if( isScreenSaverActive() )
+  {
+    // Just a bit more, so idle status will be reported
+    timeIdle = triggerTime_ + 1;
+  }
+  // If the MIT X extension is on, check with this method
+  else if( mitAvailable_ )
   {
-    // ... then use that
     timeIdle = getMitIdle();
   }
+  // Otherwise, find out when was the last mouse movement
   else
   {
     timeIdle = getMouseIdle();
@@ -102,13 +110,12 @@ void XAutoLock::checkIdle()
   if ( timeIdle > triggerTime_ && active_ )
   {
     emit timeout();
-    idle_=true;
+    idle_ = true;
   }
-  else
+  else if( idle_ )
   {
-    if ( idle_ ) resetTimer();
+    resetTimer();
   }
-
 }
 
 
@@ -134,6 +141,51 @@ unsigned int XAutoLock::getMouseIdle()
 }
 
 
+// Get screen saver status by asking the MIT-SCREEN-SAVER extension (if available)
+bool XAutoLock::isMitScreenSaverActive()
+{
+  #ifdef HAVE_XSCREENSAVER
+    if( ! mitAvailable_ )
+      return false;
+
+    XScreenSaverInfo *info = XScreenSaverAllocInfo();
+    XScreenSaverQueryInfo( qt_xdisplay(), DefaultRootWindow( qt_xdisplay() ), info );
+
+    bool state = ( info->state == ScreenSaverOn );
+
+    delete info;
+    return state;
+  #else
+    return false;
+  #endif
+}
+
+
+// Get screen saver status by asking the KDE Screen Saver or X extensions
+bool XAutoLock::isScreenSaverActive()
+{
+  QCString    replyType;
+  QByteArray  args, replyData;
+  DCOPClient *dcop = kapp->dcopClient();
+
+  // Call KScreenSaver with DCOP to find if it's on (timeouts after 1s)
+  if(    dcop
+      && dcop->call( "kdesktop", "KScreensaverIface", "isBlanked", args, replyType, replyData, true, 1000 )
+      && replyType == "bool" )
+  {
+    // Extract data
+    bool returnValue;
+    QDataStream reply( replyData, IO_ReadOnly );
+    reply >> returnValue;
+
+    return returnValue;
+  }
+
+  // As a fallback, when the DCOP call fails, ask the MIT-SCREEN-SAVER extension.
+  return isMitScreenSaverActive();
+}
+
+
 // Reset the timer (after we've just become active again, for example)
 void XAutoLock::resetTimer()
 {
