@@ -19,7 +19,6 @@
 #ifndef XAUTOLOCK_H
 #define XAUTOLOCK_H
 
-#include "../config.h"
 
 #include <qobject.h>
 #include <qtimer.h>
@@ -56,6 +55,10 @@ class XAutoLock : public QObject
     void startTimer();
     // Stop the idle timer
     void stopTimer();
+    // Get screen saver status by asking the MIT-SCREEN-SAVER extension (if available)
+    bool isMitScreenSaverActive();
+    // Get screen saver status by asking the KDE Screen Saver or X extensions
+    bool isScreenSaverActive();
 
   public slots:
     // The main function which checks for idle status
